package widebase.stream

import java.io. { File, FileInputStream }
import java.util.Properties

import net.liftweb.common. { Loggable, Logger }

import msgpack.rpcx.Server
import msgpack.rpcx.auth.AuthMap

import vario.filter.StreamFilter

class Main extends xsbti.AppMain with Logger with Loggable {

	protected class Exit(val code: Int) extends xsbti.Exit

	def run(configuration: xsbti.AppConfiguration) = {

    Main.main(configuration.arguments)

    new Exit(0)

	}
}

object Main extends Logger with Loggable {

  import scala.collection.JavaConversions._

  import widebase.rq

  protected var auths: AuthMap = _
  protected var filter: String = _
  protected var interval: Int = _
  protected var jaas: String = _
  protected var port: Int = _
  protected var expire: Int = _
  protected var path: String = _

  def main(args: Array[String]) {

    auths = new AuthMap
    filter = ""
    interval = 0
    jaas = "widebase-stream"
    port = 64608
    expire = 300
    path = "."

    var i = 0

    while(i < args.size) {

      args(i) match {

        case "-a" =>
          i += 1
          val props = new Properties
          props.load(new FileInputStream(args(i)))
          enumerationAsScalaIterator(props.propertyNames).foreach {

            case function: String =>
              auths += function -> props.getProperty(function).split(",")

          }

        case "-f" =>
          i += 1
          filter = args(i)

        case "-i" =>
          i += 1
          interval = args(i).toInt

        case "-j" =>
          i += 1
          jaas = args(i)

        case "-p" =>
          i += 1
          port = args(i).toInt

        case "-x" =>
          i += 1
          expire = args(i).toInt

        case path: String =>
          Main.this.path = path

        case _ =>
          error("Unfamiliar with argument: " + args(i))
          sys.exit(1)

      }

      i += 1

    }

    val broker = rq.broker(path, jaas, auths, interval, filter)

    broker.listen(port, expire)

    info("Listen on " + port)

    broker.await

    info("Shutdown by remotely call done")

  }
}

